===================================
		Image Lister
===================================


This is a simple script which lists
images in a dir, by checking their
extensions, and displays the count
of jpeg, png, and tiff. Not using
file descriptors and meta even.

Run it with the ``imglister`` command:

	imglister path/to/dir/containing/images

**The actual purpose of this package was to
learn how to push packages to PyPi though.**

*This package really wouldn't provide anything
of value to you.*
